pub struct All(pub bool);Expand description
Newtype wrapper for bool where join is logical AND.
All(bool) forms a join-semilattice under the dual boolean order
(true < false):
All(a).join(&All(b)) == All(a && b)- Bottom element is
All(true)
This is useful for combining boolean conditions where “all must be true”, such as validation checks, preconditions, or invariants.
Note: The dual order may seem counterintuitive, but it makes AND
the join operation (least upper bound). This mirrors how Min uses
the dual order to make min the join.
Example
use algebra::All;
use algebra::JoinSemilattice;
let a = All(true);
let b = All(false);
assert_eq!(a.join(&b), All(false));Tuple Fields
0: boolTrait Implementations
Sourceimpl BoundedJoinSemilattice for All
impl BoundedJoinSemilattice for All
Sourcefn join_all_from_bottom<I>(it: I) -> Selfwhere
I: IntoIterator<Item = Self>,
fn join_all_from_bottom<I>(it: I) -> Selfwhere
I: IntoIterator<Item = Self>,
Join a finite iterator of values, starting from ⊥. Read more
Sourceimpl<'de> Deserialize<'de> for All
impl<'de> Deserialize<'de> for All
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JoinSemilattice for All
impl JoinSemilattice for All
Sourcefn join_assign(&mut self, other: &Self)
fn join_assign(&mut self, other: &Self)
In-place variant.
Sourcefn leq(&self, other: &Self) -> boolwhere
Self: PartialEq,
fn leq(&self, other: &Self) -> boolwhere
Self: PartialEq,
Derived partial order: x ≤ y iff x ⊔ y = y.
Sourcefn join_all<I>(it: I) -> Option<Self>where
I: IntoIterator<Item = Self>,
fn join_all<I>(it: I) -> Option<Self>where
I: IntoIterator<Item = Self>,
Join a finite iterator of values. Returns
None for empty
iterators.Sourceimpl Named for All
impl Named for All
Sourcefn typename() -> &'static str
fn typename() -> &'static str
The globally unique type name for the type.
This should typically be the fully qualified Rust name of the type.
Sourcefn typehash() -> u64
fn typehash() -> u64
A globally unique hash for this type.
TODO: actually enforce perfect hashing
fn typeid() -> TypeId
fn typeid() -> TypeId
The TypeId for this type. TypeIds are unique only within a binary,
and should not be used for global identification.
fn port() -> u64
fn port() -> u64
The globally unique port for this type. Typed ports are in the range
of 1<<63..1<<64-1.
impl Copy for All
impl Eq for All
impl StructuralPartialEq for All