pub struct Any(pub bool);Expand description
Newtype wrapper for bool where join is logical OR.
join = a || bbottom = false
Example
use algebra::Any;
use algebra::JoinSemilattice;
let a = Any(false);
let b = Any(true);
assert_eq!(a.join(&b), Any(true));Tuple Fields
0: boolTrait Implementations
Sourceimpl BoundedJoinSemilattice for Any
impl BoundedJoinSemilattice for Any
Sourcefn join_all_from_bottom<I>(it: I) -> Selfwhere
I: IntoIterator<Item = Self>,
fn join_all_from_bottom<I>(it: I) -> Selfwhere
I: IntoIterator<Item = Self>,
Join a finite iterator of values, starting from ⊥. Read more
Sourceimpl<'de> Deserialize<'de> for Any
impl<'de> Deserialize<'de> for Any
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JoinSemilattice for Any
impl JoinSemilattice for Any
Sourcefn join_assign(&mut self, other: &Self)
fn join_assign(&mut self, other: &Self)
In-place variant.
Sourcefn leq(&self, other: &Self) -> boolwhere
Self: PartialEq,
fn leq(&self, other: &Self) -> boolwhere
Self: PartialEq,
Derived partial order: x ≤ y iff x ⊔ y = y.
Sourcefn join_all<I>(it: I) -> Option<Self>where
I: IntoIterator<Item = Self>,
fn join_all<I>(it: I) -> Option<Self>where
I: IntoIterator<Item = Self>,
Join a finite iterator of values. Returns
None for empty
iterators.Sourceimpl Named for Any
impl Named for Any
Sourcefn typename() -> &'static str
fn typename() -> &'static str
The globally unique type name for the type.
This should typically be the fully qualified Rust name of the type.
Sourcefn typehash() -> u64
fn typehash() -> u64
A globally unique hash for this type.
TODO: actually enforce perfect hashing
fn typeid() -> TypeId
fn typeid() -> TypeId
The TypeId for this type. TypeIds are unique only within a binary,
and should not be used for global identification.
fn port() -> u64
fn port() -> u64
The globally unique port for this type. Typed ports are in the range
of 1<<63..1<<64-1.
Sourceimpl Ord for Any
impl Ord for Any
Sourceimpl PartialOrd for Any
impl PartialOrd for Any
impl Copy for Any
impl Eq for Any
impl StructuralPartialEq for Any